# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: v1/rules/schedule_work.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from omni.pro.protos.common import base_pb2 as common_dot_base__pb2
from omni.pro.protos.v1.rules import calendar_pb2 as v1_dot_rules_dot_calendar__pb2
from omni.pro.protos.v1.rules import schedule_work_line_pb2 as v1_dot_rules_dot_schedule__work__line__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x1cv1/rules/schedule_work.proto\x12\'pro.omni.oms.api.v1.rules.schedule_work\x1a\x11\x63ommon/base.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a!v1/rules/schedule_work_line.proto\x1a\x17v1/rules/calendar.proto"\xb5\x02\n\x0cScheduleWork\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x41\n\x0b\x63\x61lendar_id\x18\x03 \x01(\x0b\x32,.pro.omni.oms.api.v1.rules.calendar.Calendar\x12[\n\x13schedule_work_lines\x18\x04 \x03(\x0b\x32>.pro.omni.oms.api.v1.rules.schedule_work_line.ScheduleWorkLine\x12*\n\x06\x61\x63tive\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12?\n\x0cobject_audit\x18\x06 \x01(\x0b\x32).pro.omni.oms.api.common.base.ObjectAudit"v\n\x19ScheduleWorkCreateRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0b\x63\x61lendar_id\x18\x02 \x01(\t\x12\x36\n\x07\x63ontext\x18\x04 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xb5\x01\n\x1aScheduleWorkCreateResponse\x12L\n\rschedule_work\x18\x01 \x01(\x0b\x32\x35.pro.omni.oms.api.v1.rules.schedule_work.ScheduleWork\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\xf5\x02\n\x17ScheduleWorkReadRequest\x12\x37\n\x08group_by\x18\x01 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x05 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\n\n\x02id\x18\x06 \x01(\t\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xef\x01\n\x18ScheduleWorkReadResponse\x12M\n\x0eschedules_work\x18\x01 \x03(\x0b\x32\x35.pro.omni.oms.api.v1.rules.schedule_work.ScheduleWork\x12\x39\n\tmeta_data\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData\x12I\n\x11response_standard\x18\x03 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\xa1\x01\n\x19ScheduleWorkUpdateRequest\x12L\n\rschedule_work\x18\x01 \x01(\x0b\x32\x35.pro.omni.oms.api.v1.rules.schedule_work.ScheduleWork\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xb5\x01\n\x1aScheduleWorkUpdateResponse\x12L\n\rschedule_work\x18\x01 \x01(\x0b\x32\x35.pro.omni.oms.api.v1.rules.schedule_work.ScheduleWork\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"_\n\x19ScheduleWorkDeleteRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"g\n\x1aScheduleWorkDeleteResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\x8e\x01\n\x1a\x41\x64\x64ScheduleWorkLineRequest\x12\x18\n\x10schedule_work_id\x18\x01 \x01(\t\x12\x1e\n\x16schedule_work_line_ids\x18\x02 \x03(\t\x12\x36\n\x07\x63ontext\x18\x03 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xb6\x01\n\x1b\x41\x64\x64ScheduleWorkLineResponse\x12L\n\rschedule_work\x18\x01 \x01(\x0b\x32\x35.pro.omni.oms.api.v1.rules.schedule_work.ScheduleWork\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\x91\x01\n\x1dRemoveScheduleWorkLineRequest\x12\x18\n\x10schedule_work_id\x18\x01 \x01(\t\x12\x1e\n\x16schedule_work_line_ids\x18\x02 \x03(\t\x12\x36\n\x07\x63ontext\x18\x03 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xb9\x01\n\x1eRemoveScheduleWorkLineResponse\x12L\n\rschedule_work\x18\x01 \x01(\x0b\x32\x35.pro.omni.oms.api.v1.rules.schedule_work.ScheduleWork\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard2\xea\x07\n\x13ScheduleWorkService\x12\x9f\x01\n\x12ScheduleWorkCreate\x12\x42.pro.omni.oms.api.v1.rules.schedule_work.ScheduleWorkCreateRequest\x1a\x43.pro.omni.oms.api.v1.rules.schedule_work.ScheduleWorkCreateResponse"\x00\x12\x99\x01\n\x10ScheduleWorkRead\x12@.pro.omni.oms.api.v1.rules.schedule_work.ScheduleWorkReadRequest\x1a\x41.pro.omni.oms.api.v1.rules.schedule_work.ScheduleWorkReadResponse"\x00\x12\x9f\x01\n\x12ScheduleWorkUpdate\x12\x42.pro.omni.oms.api.v1.rules.schedule_work.ScheduleWorkUpdateRequest\x1a\x43.pro.omni.oms.api.v1.rules.schedule_work.ScheduleWorkUpdateResponse"\x00\x12\x9f\x01\n\x12ScheduleWorkDelete\x12\x42.pro.omni.oms.api.v1.rules.schedule_work.ScheduleWorkDeleteRequest\x1a\x43.pro.omni.oms.api.v1.rules.schedule_work.ScheduleWorkDeleteResponse"\x00\x12\xa2\x01\n\x13\x41\x64\x64ScheduleWorkLine\x12\x43.pro.omni.oms.api.v1.rules.schedule_work.AddScheduleWorkLineRequest\x1a\x44.pro.omni.oms.api.v1.rules.schedule_work.AddScheduleWorkLineResponse"\x00\x12\xab\x01\n\x16RemoveScheduleWorkLine\x12\x46.pro.omni.oms.api.v1.rules.schedule_work.RemoveScheduleWorkLineRequest\x1aG.pro.omni.oms.api.v1.rules.schedule_work.RemoveScheduleWorkLineResponse"\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "v1.rules.schedule_work_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _globals["_SCHEDULEWORK"]._serialized_start = 185
    _globals["_SCHEDULEWORK"]._serialized_end = 494
    _globals["_SCHEDULEWORKCREATEREQUEST"]._serialized_start = 496
    _globals["_SCHEDULEWORKCREATEREQUEST"]._serialized_end = 614
    _globals["_SCHEDULEWORKCREATERESPONSE"]._serialized_start = 617
    _globals["_SCHEDULEWORKCREATERESPONSE"]._serialized_end = 798
    _globals["_SCHEDULEWORKREADREQUEST"]._serialized_start = 801
    _globals["_SCHEDULEWORKREADREQUEST"]._serialized_end = 1174
    _globals["_SCHEDULEWORKREADRESPONSE"]._serialized_start = 1177
    _globals["_SCHEDULEWORKREADRESPONSE"]._serialized_end = 1416
    _globals["_SCHEDULEWORKUPDATEREQUEST"]._serialized_start = 1419
    _globals["_SCHEDULEWORKUPDATEREQUEST"]._serialized_end = 1580
    _globals["_SCHEDULEWORKUPDATERESPONSE"]._serialized_start = 1583
    _globals["_SCHEDULEWORKUPDATERESPONSE"]._serialized_end = 1764
    _globals["_SCHEDULEWORKDELETEREQUEST"]._serialized_start = 1766
    _globals["_SCHEDULEWORKDELETEREQUEST"]._serialized_end = 1861
    _globals["_SCHEDULEWORKDELETERESPONSE"]._serialized_start = 1863
    _globals["_SCHEDULEWORKDELETERESPONSE"]._serialized_end = 1966
    _globals["_ADDSCHEDULEWORKLINEREQUEST"]._serialized_start = 1969
    _globals["_ADDSCHEDULEWORKLINEREQUEST"]._serialized_end = 2111
    _globals["_ADDSCHEDULEWORKLINERESPONSE"]._serialized_start = 2114
    _globals["_ADDSCHEDULEWORKLINERESPONSE"]._serialized_end = 2296
    _globals["_REMOVESCHEDULEWORKLINEREQUEST"]._serialized_start = 2299
    _globals["_REMOVESCHEDULEWORKLINEREQUEST"]._serialized_end = 2444
    _globals["_REMOVESCHEDULEWORKLINERESPONSE"]._serialized_start = 2447
    _globals["_REMOVESCHEDULEWORKLINERESPONSE"]._serialized_end = 2632
    _globals["_SCHEDULEWORKSERVICE"]._serialized_start = 2635
    _globals["_SCHEDULEWORKSERVICE"]._serialized_end = 3637
# @@protoc_insertion_point(module_scope)
