# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: v1/stock/route.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from omni.pro.protos.common import base_pb2 as common_dot_base__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x14v1/stock/route.proto\x12\x1fpro.omni.oms.api.v1.stock.route\x1a\x11\x63ommon/base.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1egoogle/protobuf/wrappers.proto"\x9e\x03\n\x05Route\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x10\n\x08sequence\x18\x03 \x01(\x05\x12<\n\x18product_categ_selectable\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x36\n\x12product_selectable\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x36\n\x12packing_selectable\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x38\n\x14warehouse_selectable\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x14\n\x0cwarehouse_id\x18\x08 \x01(\x05\x12*\n\x06\x61\x63tive\x18\t \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12?\n\x0cobject_audit\x18\n \x01(\x0b\x32).pro.omni.oms.api.common.base.ObjectAudit"\xea\x02\n\x12RouteCreateRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x10\n\x08sequence\x18\x02 \x01(\x05\x12<\n\x18product_categ_selectable\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x36\n\x12product_selectable\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x36\n\x12packing_selectable\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x38\n\x14warehouse_selectable\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x14\n\x0cwarehouse_id\x18\x07 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x08 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x97\x01\n\x13RouteCreateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x35\n\x05route\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.v1.stock.route.Route"\xee\x02\n\x10RouteReadRequest\x12\x37\n\x08group_by\x18\x01 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x05 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\n\n\x02id\x18\x06 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xd1\x01\n\x11RouteReadResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x39\n\tmeta_data\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData\x12\x36\n\x06routes\x18\x03 \x03(\x0b\x32&.pro.omni.oms.api.v1.stock.route.Route"\x83\x01\n\x12RouteUpdateRequest\x12\x35\n\x05route\x18\x01 \x01(\x0b\x32&.pro.omni.oms.api.v1.stock.route.Route\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x97\x01\n\x13RouteUpdateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x35\n\x05route\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.v1.stock.route.Route"X\n\x12RouteDeleteRequest\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"`\n\x13RouteDeleteResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard2\xf8\x03\n\x0cRouteService\x12z\n\x0bRouteCreate\x12\x33.pro.omni.oms.api.v1.stock.route.RouteCreateRequest\x1a\x34.pro.omni.oms.api.v1.stock.route.RouteCreateResponse"\x00\x12t\n\tRouteRead\x12\x31.pro.omni.oms.api.v1.stock.route.RouteReadRequest\x1a\x32.pro.omni.oms.api.v1.stock.route.RouteReadResponse"\x00\x12z\n\x0bRouteUpdate\x12\x33.pro.omni.oms.api.v1.stock.route.RouteUpdateRequest\x1a\x34.pro.omni.oms.api.v1.stock.route.RouteUpdateResponse"\x00\x12z\n\x0bRouteDelete\x12\x33.pro.omni.oms.api.v1.stock.route.RouteDeleteRequest\x1a\x34.pro.omni.oms.api.v1.stock.route.RouteDeleteResponse"\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "v1.stock.route_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _globals["_ROUTE"]._serialized_start = 139
    _globals["_ROUTE"]._serialized_end = 553
    _globals["_ROUTECREATEREQUEST"]._serialized_start = 556
    _globals["_ROUTECREATEREQUEST"]._serialized_end = 918
    _globals["_ROUTECREATERESPONSE"]._serialized_start = 921
    _globals["_ROUTECREATERESPONSE"]._serialized_end = 1072
    _globals["_ROUTEREADREQUEST"]._serialized_start = 1075
    _globals["_ROUTEREADREQUEST"]._serialized_end = 1441
    _globals["_ROUTEREADRESPONSE"]._serialized_start = 1444
    _globals["_ROUTEREADRESPONSE"]._serialized_end = 1653
    _globals["_ROUTEUPDATEREQUEST"]._serialized_start = 1656
    _globals["_ROUTEUPDATEREQUEST"]._serialized_end = 1787
    _globals["_ROUTEUPDATERESPONSE"]._serialized_start = 1790
    _globals["_ROUTEUPDATERESPONSE"]._serialized_end = 1941
    _globals["_ROUTEDELETEREQUEST"]._serialized_start = 1943
    _globals["_ROUTEDELETEREQUEST"]._serialized_end = 2031
    _globals["_ROUTEDELETERESPONSE"]._serialized_start = 2033
    _globals["_ROUTEDELETERESPONSE"]._serialized_end = 2129
    _globals["_ROUTESERVICE"]._serialized_start = 2132
    _globals["_ROUTESERVICE"]._serialized_end = 2636
# @@protoc_insertion_point(module_scope)
